@@ -221,15 +221,15 @@ function _fq_default_ctx_type(F::FqField)
 end
 
 function _get_raw_type(::Type{fqPolyRepField}, F::FqField)
-  @assert _fq_default_ctx_type(F) == 2
-  Rx, _ = polynomial_ring(Native.GF(UInt(characteristic(F))), "x", cached = false)
+  @assert _fq_default_ctx_type(F) == _FQ_DEFAULT_FQ_NMOD
+  Rx, _ = polynomial_ring(Native.GF(UInt(characteristic(F))), :x, cached = false)
   m = map_coefficients(x -> _coeff(x, 0), defining_polynomial(F), parent = Rx)
   return fqPolyRepField(m, :$, false)
 end
 
 function _get_raw_type(::Type{FqPolyRepField}, F::FqField)
-  @assert _fq_default_ctx_type(F) == 3
-  Rx, _ = polynomial_ring(Native.GF(characteristic(F)), "x", cached = false)
+  @assert _fq_default_ctx_type(F) == _FQ_DEFAULT_FQ
+  Rx, _ = polynomial_ring(Native.GF(characteristic(F)), :x, cached = false)
   m = map_coefficients(x -> _coeff(x, 0), defining_polynomial(F), parent = Rx)
   return FqPolyRepField(m, :$, false)
 end
@@ -240,12 +240,12 @@ function canonical_raw_type(::Type{T}, F::FqField) where {T}
 end
 
 function _get_raw_type(::Type{fpField}, F::FqField)
-  @assert _fq_default_ctx_type(F) == 4
+  @assert _fq_default_ctx_type(F) == _FQ_DEFAULT_NMOD
   return Native.GF(UInt(order(F)), cached = false)
 end
 
 function _get_raw_type(::Type{FpField}, F::FqField)
-  @assert _fq_default_ctx_type(F) == 5
+  @assert _fq_default_ctx_type(F) == _FQ_DEFAULT_FMPZ_NMOD
   return Native.GF(order(F), cached = false)
 end
 
