@@ -118,6 +118,11 @@ for (etype, rtype, ftype, ctype, utype) in (
       return base_ring(parent(a))(z)
     end
 
+    function coeff!(b::($ctype), a::($etype), i::Int)
+      # Cannot do anything inplace here because b is immutable
+      return coeff(a, i)
+    end
+
     function coeff(a::($etype), b::($etype))
       check_parent(a, b)
       !isone(length(b)) && error("Second argument must be a monomial")
@@ -834,6 +839,10 @@ for (etype, rtype, ftype, ctype, utype) in (
     # Return the i-th term of the polynomial, as a polynomial
     function term(a::($etype), i::Int)
       z = parent(a)()
+      return term!(z, a, i)
+    end
+
+    function term!(z::($etype), a::($etype), i::Int)
       @ccall libflint.nmod_mpoly_get_term(z::Ref{($etype)}, a::Ref{($etype)}, (i - 1)::Int, parent(a)::Ref{($rtype)})::Nothing
       return z
     end
@@ -841,8 +850,7 @@ for (etype, rtype, ftype, ctype, utype) in (
     # Return the i-th monomial of the polynomial, as a polynomial
     function monomial(a::($etype), i::Int)
       z = parent(a)()
-      @ccall libflint.nmod_mpoly_get_term_monomial(z::Ref{($etype)}, a::Ref{($etype)}, (i - 1)::Int, a.parent::Ref{($rtype)})::Nothing
-      return z
+      return monomial!(z, a, i)
     end
 
     # Sets the given polynomial m to the i-th monomial of the polynomial
